﻿//
// Parago Media GmbH & Co. KG, Jürgen Bäurle (jbaurle@parago.de)
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
// TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
//

using System;
using ERPConnect;
using Microsoft.SharePoint.WebControls;

namespace SP2010SecureStoreSAP.ApplicationPages
{
	public partial class SecureStoreSAPTestPage : LayoutsPageBase
	{
		protected void OnTestButtonClick(object sender, EventArgs e)
		{
			// ------------------------------------------------------------------------------------------------------------------------------------
			//
			// IMPORTANT NOTICE!
			//
			// Replace license key for ERPConnect library and SAP connection string with your own data. To get a trail license key for ERPConnect
			// please contact me (jbaurle@parago.de) or the support team from Theobald Software at http://www.theobald-software.com.
			//
			// ------------------------------------------------------------------------------------------------------------------------------------

			string licenseKey = "<LICENSEKEY>";
			string connectionStringFormat = "CLIENT=800 LANG=EN USER={0} PASSWD={1} ASHOST=HAMLET SYSNR=05";

			// ------------------------------------------------------------------------------------------------------------------------------------

			R3Connection connection = null;

			try
			{
				LIC.SetLic(licenseKey);

				if(string.IsNullOrEmpty(ApplicationID.Text))
				{
					WriteErrorMessage("Target application ID is not entered.");
					return;
				}

				SecureStoreCredentials credentials = new SecureStore(ApplicationID.Text).GetCurrentCredentials();
				string connectionstring = string.Format(connectionStringFormat, credentials.UserName, credentials.Password);

				connection = new R3Connection(connectionstring);
				connection.Open();

				RFCFunction function = connection.CreateFunction("SD_RFC_CUSTOMER_GET");
				function.Exports["NAME1"].ParamValue = "Te*";
				function.Execute();

				ResultGrid.DataSource = function.Tables["CUSTOMER_T"].ToADOTable();
				ResultGrid.DataBind();

				OutputLabel.Text = string.Format("The test called the SAP function module '<b>SD_RFC_CUSTOMER_GET</b>' to return all customers where the name starts with '<b>Te*</b>'. The ERPConnect library connected to the SAP system using the credentials saved in the secure store with name '<b>{0}</b>'. The SAP user name found in the secure store for the current user '<b>{1}</b>' ('<b>{2}</b>') is '<b>{3}</b>'.", ApplicationID.Text, Web.CurrentUser.Name, Web.CurrentUser.LoginName, credentials.UserName);
			}
			catch(Exception ex)
			{
				WriteErrorMessage(ex.Message);
			}
			finally
			{
				if(connection != null && connection.Ping())
					connection.Close();
			}
		}

		#region Helper Methods

		void WriteErrorMessage(string message)
		{
			MessagePanel.Visible = true;
			ErrorLabel.Text = message;
		}

		void WriteErrorMessage(string format, params object[] arg)
		{
			WriteErrorMessage(string.Format(format, arg));
		}

		#endregion
	}
}
